@@ -35,8 +35,8 @@ USAGE() {
     echo "OPTION:"
     echo "-b, --boot-loader [grub|syslinux]  Assign grub or syslinux as boot loader in target device"
     echo "-f, --force                        Force to do that, i.e. without confirm."
-    echo "-k, --kernel-file FILENAME         Provide the kernel name, which wiil be used in the menu.lst or syslinux.cfg. If unset, $KERNEL_FILE_DEFAULT will be used" 
-    echo "-i, --initrd-file FILENAME         Provide the initrd name, which wiil be used in the menu.lst or syslinux.cfg. If unset, $INITRD_FILE_DEFAULT will be used" 
+    echo "-k, --kernel-file FILENAME         Provide the kernel name to be used in the config file (menu.lst or syslinux.cfg) of boot manager (with absolute path if necessary, Ex: /casper/vmlinuz1). If unset, $KERNEL_FILE_DEFAULT will be used" 
+    echo "-i, --initrd-file FILENAME         Provide the initrd name to be used in the config file (menu.lst or syslinux.cfg) of boot manager (with absolute path if necessary, Ex: /casper/vmlinuz1). If unset, $INITRD_FILE_DEFAULT will be used" 
     echo "-p, --boot-param  PARAM            Provide the append strings for kernel bootparam. which wiil be used in the menu.lst or syslinux.cfg. If unset, $BOOT_PARAM_DEFAULT will be used" 
     echo "Ex:"
     echo "To make a USB device /dev/sda1 bootable, you can run:"
